<?php

namespace Drupal\monarch_migration_tools\Plugin\migrate\destination;

use Drupal\migrate\Row;
use Drupal\Core\Serialization\Yaml;
use Drupal\migrate\Plugin\migrate\destination\DestinationBase;

/**
 * Provides a plugin to dump source/destination values to file.
 *
 * @MigrateDestination(
 *   id = "dump",
 * )
 */
class Dump extends DestinationBase {

  /**
   * The sequence number.
   *
   * @var int
   */
  protected $seq = 0;

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    return [
      'seq' => [
        'type' => 'string',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function fields() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function import(Row $row, array $old_destination_id_values = []) {
    $seq = $this->seq++;

    /** @var \Drupal\Core\File\FileSystemInterface $fs */
    $fs = \Drupal::service('file_system');
    $dir = implode('/', array_filter([
      'public://migration_dump',
      $this->migration->id(),
      $row->getDestinationProperty('dump'),
      $row->getSourceProperty('bundle'),
    ]));

    $fs->prepareDirectory($dir, $fs::CREATE_DIRECTORY | $fs::MODIFY_PERMISSIONS);

    $path = $dir . '/' . $seq . '.yml';

    file_put_contents($path, Yaml::encode([
      'source' => $row->getSource(),
      'destination' => $row->getDestination(),
    ], JSON_PRETTY_PRINT));

    return [$seq];
  }

}
